aboutsummaryrefslogtreecommitdiffstats
path: root/zetrename.sh
diff options
context:
space:
mode:
Diffstat (limited to '')
-rwxr-xr-xzetrename.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/zetrename.sh b/zetrename.sh
index 8cb5497..e1a178d 100755
--- a/zetrename.sh
+++ b/zetrename.sh
@@ -1,8 +1,8 @@
-#!/usr/local/bin/bash
+#!/usr/bin/bash
# Renaming files of the format YYYYMMDDHHMMSS-title text etc.md is a massive pain, so this script does it for you.
-NOTES=/home/$USER/Notes/modzet
+NOTES=/home/$USER/Documents/Notes/modzet
function usage {
echo
@@ -15,7 +15,7 @@ if [[ $# -eq 0 ]]; then
usage; exit 1
fi
# path must be of form /home/$USER/Notes/modzet/20220419133511-Title of file.md
#re='^/tmp\/Notes\/modzet\/(.{14})-(.+)\.md'
re='^/home\/lemon\/Notes\/modzet\/(.{14})-(.+)\.md'
@@ -15,7 +15,7 @@ if [[ $# -eq 0 ]]; then
usage; exit 1
fi
-# path must be of form /home/$USER/Notes/modzet/20220419133511-Title of file.md
+# path must be of form /home/$USER/Documents/Notes/modzet/20220419133511-Title of file.md
#re='^/tmp\/Notes\/modzet\/(.{14})-(.+)\.md'
re='^/home\/lemon\/Notes\/modzet\/(.{14})-(.+)\.md'